@@ -10,13 +10,12 @@
 __all__ = ['ElevationGridFile']
 
 import os
-import sys
 
 from osgeo import gdalconst
 from gazar.grid import resample_grid
 
 from .map import RasterMapFile
-
+from ..util.context import tmp_chdir
 
 class ElevationGridFile(RasterMapFile):
     """
@@ -43,8 +42,9 @@ class ElevationGridFile(RasterMapFile):
                            elevation_raster,
                            shapefile_path=None,
                            out_elevation_grid=None,
-                           resample_method=gdalconst.GRA_Average):
-        '''
+                           resample_method=gdalconst.GRA_Average,
+                           load_raster_to_db=True):
+        """
         Generates an elevation grid for the GSSHA simulation
         from an elevation raster
 
@@ -53,19 +53,15 @@ class ElevationGridFile(RasterMapFile):
             from gsshapy.orm import ProjectFile, ElevationGridFile
             from gsshapy.lib import db_tools as dbt
 
-            from os import path, chdir
 
             gssha_directory = '/gsshapy/tests/grid_standard/gssha_project'
             elevation_raster = 'elevation.tif'
 
-            # Create Test DB
-            sqlalchemy_url, sql_engine = dbt.init_sqlite_memory()
+            project_manager, db_sessionmaker = \
+                dbt.get_project_session('grid_standard',
+                                        gssha_directory)
 
-            # Create DB Sessions
-            db_session = dbt.create_session(sqlalchemy_url, sql_engine)
-
-            # Instantiate GSSHAPY object for reading to database
-            project_manager = ProjectFile()
+            db_session = db_sessionmaker()
 
             # read project file
             project_manager.readInput(directory=gssha_directory,
@@ -81,31 +77,34 @@ class ElevationGridFile(RasterMapFile):
             project_manager.writeInput(session=db_session,
                                        directory=gssha_directory,
                                        name='grid_standard')
-        '''
+        """
         if not self.projectFile:
             raise ValueError("Must be connected to project file ...")
 
+        # make sure paths are absolute as the working directory changes
+        elevation_raster = os.path.abspath(elevation_raster)
+        shapefile_path = os.path.abspath(shapefile_path)
+
         # must match elevation mask grid
         mask_grid = self.projectFile.getGrid()
         if out_elevation_grid is None:
-            project_path = ''
-            project_path_card = self.projectFile.getCard('PROJECT_PATH')
-            if project_path_card:
-                project_path = project_path_card.value.strip('"').strip("'")
-            out_elevation_grid = os.path.join(project_path,
-                                              '{0}.{1}'.format(self.projectFile.name,
-                                                               self.fileExtension),
-                                              )
+            out_elevation_grid = '{0}.{1}'.format(self.projectFile.name,
+                                                  self.fileExtension)
 
         elevation_grid = resample_grid(elevation_raster,
                                        mask_grid,
                                        resample_method=resample_method,
                                        as_gdal_grid=True)
-        elevation_grid.to_grass_ascii(out_elevation_grid, print_nodata=False)
+
+        with tmp_chdir(self.projectFile.project_directory):
+            elevation_grid.to_grass_ascii(out_elevation_grid, print_nodata=False)
+
+            # read raster into object
+            if load_raster_to_db:
+                self._load_raster_text(out_elevation_grid)
 
         self.filename = out_elevation_grid
         self.projectFile.setCard("ELEVATION", out_elevation_grid, add_quotes=True)
-        # read raster into object
-        self._load_raster_text(out_elevation_grid)
+
         # find outlet and add slope
         self.projectFile.findOutlet(shapefile_path)
